import { PlainObject } from '@cypress/schema-tools';
import { ISODateString, hookId, milliseconds, testId, testState } from '../objects';
export declare type TestRunnerTestCommonFields = {
    state: testState;
    failedFromHookId: hookId | null;
    wallClockStartedAt: ISODateString | null;
    wallClockDuration: milliseconds | null;
    videoTimestamp: milliseconds | null;
};
export declare type TestRunnerTestCommonV1Fields = {
    state: testState;
    stack: string | null;
    error: string | null;
    timings: PlainObject | null;
};
export declare type TestRunnerTestExample100 = TestRunnerTestCommonFields & TestRunnerTestCommonV1Fields & {
    testId: testId;
    title: string[];
    body: string | null;
};
export declare const testRunnerTestExample100: TestRunnerTestExample100;
export declare const BaseTestProperties: {
    state: {
        type: "string";
        format: string;
    };
};
export declare const BaseTestExecutionProperties: {
    failedFromHookId: {
        type: string[];
        format: string;
    };
    wallClockStartedAt: {
        type: string[];
        format: string;
    };
    wallClockDuration: {
        type: string[];
        minimum: number;
    };
    videoTimestamp: {
        type: string[];
    };
    state: {
        type: "string";
        format: string;
    };
};
export declare const CommonTestProperties: {
    testId: {
        type: "string";
        format: string;
        description: string;
    };
    title: {
        type: "array";
        items: {
            type: "string";
        };
    };
    body: {
        type: string[];
        description: string;
    };
    state: {
        type: "string";
        format: string;
    };
};
export declare const CommonTestPropertiesV1: {
    stack: {
        type: string[];
        description: string;
    };
    error: {
        type: string[];
        description: string;
    };
    timings: {
        type: string[];
        description: string;
        properties: {
            lifecycle: {
                type: "integer";
                minimum: number;
                description: string;
            };
            'before each': {
                type: "array";
                items: {
                    type: "object";
                };
            };
        };
    };
    failedFromHookId: {
        type: string[];
        format: string;
    };
    wallClockStartedAt: {
        type: string[];
        format: string;
    };
    wallClockDuration: {
        type: string[];
        minimum: number;
    };
    videoTimestamp: {
        type: string[];
    };
    state: {
        type: "string";
        format: string;
    };
    testId: {
        type: "string";
        format: string;
        description: string;
    };
    title: {
        type: "array";
        items: {
            type: "string";
        };
    };
    body: {
        type: string[];
        description: string;
    };
};
export declare const TestRunnerTest100: {
    version: {
        major: number;
        minor: number;
        patch: number;
    };
    schema: {
        title: string;
        description: string;
        type: "object";
        properties: {
            stack: {
                type: string[];
                description: string;
            };
            error: {
                type: string[];
                description: string;
            };
            timings: {
                type: string[];
                description: string;
                properties: {
                    lifecycle: {
                        type: "integer";
                        minimum: number;
                        description: string;
                    };
                    'before each': {
                        type: "array";
                        items: {
                            type: "object";
                        };
                    };
                };
            };
            failedFromHookId: {
                type: string[];
                format: string;
            };
            wallClockStartedAt: {
                type: string[];
                format: string;
            };
            wallClockDuration: {
                type: string[];
                minimum: number;
            };
            videoTimestamp: {
                type: string[];
            };
            state: {
                type: "string";
                format: string;
            };
            testId: {
                type: "string";
                format: string;
                description: string;
            };
            title: {
                type: "array";
                items: {
                    type: "string";
                };
            };
            body: {
                type: string[];
                description: string;
            };
        };
        required: true;
        additionalProperties: false;
    };
    example: TestRunnerTestExample100;
};
export declare type TestRunnerTestErrorCodeFrameExample100 = {
    line: number | null;
    column: number | null;
    originalFile: string;
    relativeFile: string;
    absoluteFile: string;
    frame: string;
    language: string;
};
export declare type TestRunnerTestErrorExample100 = {
    name: string | null;
    message: string | null;
    stack: string | null;
    codeFrame?: TestRunnerTestErrorCodeFrameExample100 | null;
};
export declare type TestRunnerTestAttemptExample100 = Pick<TestRunnerTestExample100, 'state' | 'videoTimestamp' | 'wallClockDuration' | 'wallClockStartedAt' | 'failedFromHookId'> & {
    error: TestRunnerTestErrorExample100 | null;
    timings: PlainObject | null;
};
export declare type TestRunnerTestExample200 = Pick<TestRunnerTestExample100, 'title' | 'body' | 'state' | 'testId'> & {
    displayError: string;
    attempts: TestRunnerTestAttemptExample100[];
};
export declare const testRunnerTestErrorCodeFrameExample100: TestRunnerTestErrorCodeFrameExample100;
export declare const testRunnerTestErrorExample100: TestRunnerTestErrorExample100;
export declare const testRunnerTestAttemptExample100: TestRunnerTestAttemptExample100;
export declare const testRunnerTestExample200: TestRunnerTestExample200;
export declare const TestRunnerTestErrorCodeFrame100: {
    version: {
        major: number;
        minor: number;
        patch: number;
    };
    schema: {
        type: "object";
        title: string;
        description: string;
        properties: {
            line: {
                type: string[];
                description: string;
            };
            column: {
                type: string[];
                description: string;
            };
            originalFile: {
                type: string[];
                description: string;
            };
            relativeFile: {
                type: string[];
                description: string;
            };
            absoluteFile: {
                type: string[];
                description: string;
            };
            frame: {
                type: string[];
                description: string;
            };
            language: {
                type: string[];
                description: string;
            };
        };
        additionalProperties: true;
    };
    example: TestRunnerTestErrorExample100;
};
export declare const TestRunnerTestError100: {
    version: {
        major: number;
        minor: number;
        patch: number;
    };
    schema: {
        type: "object";
        title: string;
        description: string;
        properties: {
            name: {
                type: string[];
                description: string;
            };
            message: {
                type: string[];
                description: string;
            };
            stack: {
                type: string[];
                description: string;
            };
            codeFrame: {
                type: string[];
                see: {
                    version: {
                        major: number;
                        minor: number;
                        patch: number;
                    };
                    schema: {
                        type: "object";
                        title: string;
                        description: string;
                        properties: {
                            line: {
                                type: string[];
                                description: string;
                            };
                            column: {
                                type: string[];
                                description: string;
                            };
                            originalFile: {
                                type: string[];
                                description: string;
                            };
                            relativeFile: {
                                type: string[];
                                description: string;
                            };
                            absoluteFile: {
                                type: string[];
                                description: string;
                            };
                            frame: {
                                type: string[];
                                description: string;
                            };
                            language: {
                                type: string[];
                                description: string;
                            };
                        };
                        additionalProperties: true;
                    };
                    example: TestRunnerTestErrorExample100;
                };
                required: false;
                title: string;
                description: string;
                properties: {
                    line: {
                        type: string[];
                        description: string;
                    };
                    column: {
                        type: string[];
                        description: string;
                    };
                    originalFile: {
                        type: string[];
                        description: string;
                    };
                    relativeFile: {
                        type: string[];
                        description: string;
                    };
                    absoluteFile: {
                        type: string[];
                        description: string;
                    };
                    frame: {
                        type: string[];
                        description: string;
                    };
                    language: {
                        type: string[];
                        description: string;
                    };
                };
                additionalProperties: true;
            };
        };
        additionalProperties: true;
    };
    example: TestRunnerTestErrorExample100;
};
export declare const TestRunnerTestAttempt100: {
    version: {
        major: number;
        minor: number;
        patch: number;
    };
    schema: {
        type: "object";
        title: string;
        description: string;
        properties: {
            error: {
                type: string[];
                see: {
                    version: {
                        major: number;
                        minor: number;
                        patch: number;
                    };
                    schema: {
                        type: "object";
                        title: string;
                        description: string;
                        properties: {
                            name: {
                                type: string[];
                                description: string;
                            };
                            message: {
                                type: string[];
                                description: string;
                            };
                            stack: {
                                type: string[];
                                description: string;
                            };
                            codeFrame: {
                                type: string[];
                                see: {
                                    version: {
                                        major: number;
                                        minor: number;
                                        patch: number;
                                    };
                                    schema: {
                                        type: "object";
                                        title: string;
                                        description: string;
                                        properties: {
                                            line: {
                                                type: string[];
                                                description: string;
                                            };
                                            column: {
                                                type: string[];
                                                description: string;
                                            };
                                            originalFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            relativeFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            absoluteFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            frame: {
                                                type: string[];
                                                description: string;
                                            };
                                            language: {
                                                type: string[];
                                                description: string;
                                            };
                                        };
                                        additionalProperties: true;
                                    };
                                    example: TestRunnerTestErrorExample100;
                                };
                                required: false;
                                title: string;
                                description: string;
                                properties: {
                                    line: {
                                        type: string[];
                                        description: string;
                                    };
                                    column: {
                                        type: string[];
                                        description: string;
                                    };
                                    originalFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    relativeFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    absoluteFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    frame: {
                                        type: string[];
                                        description: string;
                                    };
                                    language: {
                                        type: string[];
                                        description: string;
                                    };
                                };
                                additionalProperties: true;
                            };
                        };
                        additionalProperties: true;
                    };
                    example: TestRunnerTestErrorExample100;
                };
                title: string;
                description: string;
                properties: {
                    name: {
                        type: string[];
                        description: string;
                    };
                    message: {
                        type: string[];
                        description: string;
                    };
                    stack: {
                        type: string[];
                        description: string;
                    };
                    codeFrame: {
                        type: string[];
                        see: {
                            version: {
                                major: number;
                                minor: number;
                                patch: number;
                            };
                            schema: {
                                type: "object";
                                title: string;
                                description: string;
                                properties: {
                                    line: {
                                        type: string[];
                                        description: string;
                                    };
                                    column: {
                                        type: string[];
                                        description: string;
                                    };
                                    originalFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    relativeFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    absoluteFile: {
                                        type: string[];
                                        description: string;
                                    };
                                    frame: {
                                        type: string[];
                                        description: string;
                                    };
                                    language: {
                                        type: string[];
                                        description: string;
                                    };
                                };
                                additionalProperties: true;
                            };
                            example: TestRunnerTestErrorExample100;
                        };
                        required: false;
                        title: string;
                        description: string;
                        properties: {
                            line: {
                                type: string[];
                                description: string;
                            };
                            column: {
                                type: string[];
                                description: string;
                            };
                            originalFile: {
                                type: string[];
                                description: string;
                            };
                            relativeFile: {
                                type: string[];
                                description: string;
                            };
                            absoluteFile: {
                                type: string[];
                                description: string;
                            };
                            frame: {
                                type: string[];
                                description: string;
                            };
                            language: {
                                type: string[];
                                description: string;
                            };
                        };
                        additionalProperties: true;
                    };
                };
                additionalProperties: true;
            };
            timings: {
                type: string[];
                description: string;
                properties: {
                    lifecycle: {
                        type: "integer";
                        minimum: number;
                        description: string;
                    };
                    'before each': {
                        type: "array";
                        items: {
                            type: "object";
                        };
                    };
                };
            };
            failedFromHookId: {
                type: string[];
                format: string;
            };
            wallClockStartedAt: {
                type: string[];
                format: string;
            };
            wallClockDuration: {
                type: string[];
                minimum: number;
            };
            videoTimestamp: {
                type: string[];
            };
            state: {
                type: "string";
                format: string;
            };
        };
        additionalProperties: false;
    };
    example: TestRunnerTestAttemptExample100;
};
export declare const TestRunnerTest200: {
    version: {
        major: number;
        minor: number;
        patch: number;
    };
    schema: {
        type: "object";
        title: string;
        properties: {
            displayError: {
                type: string[];
            };
            attempts: {
                type: string[];
                items: {
                    type: "object";
                    title: string;
                    description: string;
                    properties: {
                        error: {
                            type: string[];
                            see: {
                                version: {
                                    major: number;
                                    minor: number;
                                    patch: number;
                                };
                                schema: {
                                    type: "object";
                                    title: string;
                                    description: string;
                                    properties: {
                                        name: {
                                            type: string[];
                                            description: string;
                                        };
                                        message: {
                                            type: string[];
                                            description: string;
                                        };
                                        stack: {
                                            type: string[];
                                            description: string;
                                        };
                                        codeFrame: {
                                            type: string[];
                                            see: {
                                                version: {
                                                    major: number;
                                                    minor: number;
                                                    patch: number;
                                                };
                                                schema: {
                                                    type: "object";
                                                    title: string;
                                                    description: string;
                                                    properties: {
                                                        line: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        column: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        originalFile: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        relativeFile: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        absoluteFile: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        frame: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                        language: {
                                                            type: string[];
                                                            description: string;
                                                        };
                                                    };
                                                    additionalProperties: true;
                                                };
                                                example: TestRunnerTestErrorExample100;
                                            };
                                            required: false;
                                            title: string;
                                            description: string;
                                            properties: {
                                                line: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                column: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                originalFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                relativeFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                absoluteFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                frame: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                language: {
                                                    type: string[];
                                                    description: string;
                                                };
                                            };
                                            additionalProperties: true;
                                        };
                                    };
                                    additionalProperties: true;
                                };
                                example: TestRunnerTestErrorExample100;
                            };
                            title: string;
                            description: string;
                            properties: {
                                name: {
                                    type: string[];
                                    description: string;
                                };
                                message: {
                                    type: string[];
                                    description: string;
                                };
                                stack: {
                                    type: string[];
                                    description: string;
                                };
                                codeFrame: {
                                    type: string[];
                                    see: {
                                        version: {
                                            major: number;
                                            minor: number;
                                            patch: number;
                                        };
                                        schema: {
                                            type: "object";
                                            title: string;
                                            description: string;
                                            properties: {
                                                line: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                column: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                originalFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                relativeFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                absoluteFile: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                frame: {
                                                    type: string[];
                                                    description: string;
                                                };
                                                language: {
                                                    type: string[];
                                                    description: string;
                                                };
                                            };
                                            additionalProperties: true;
                                        };
                                        example: TestRunnerTestErrorExample100;
                                    };
                                    required: false;
                                    title: string;
                                    description: string;
                                    properties: {
                                        line: {
                                            type: string[];
                                            description: string;
                                        };
                                        column: {
                                            type: string[];
                                            description: string;
                                        };
                                        originalFile: {
                                            type: string[];
                                            description: string;
                                        };
                                        relativeFile: {
                                            type: string[];
                                            description: string;
                                        };
                                        absoluteFile: {
                                            type: string[];
                                            description: string;
                                        };
                                        frame: {
                                            type: string[];
                                            description: string;
                                        };
                                        language: {
                                            type: string[];
                                            description: string;
                                        };
                                    };
                                    additionalProperties: true;
                                };
                            };
                            additionalProperties: true;
                        };
                        timings: {
                            type: string[];
                            description: string;
                            properties: {
                                lifecycle: {
                                    type: "integer";
                                    minimum: number;
                                    description: string;
                                };
                                'before each': {
                                    type: "array";
                                    items: {
                                        type: "object";
                                    };
                                };
                            };
                        };
                        failedFromHookId: {
                            type: string[];
                            format: string;
                        };
                        wallClockStartedAt: {
                            type: string[];
                            format: string;
                        };
                        wallClockDuration: {
                            type: string[];
                            minimum: number;
                        };
                        videoTimestamp: {
                            type: string[];
                        };
                        state: {
                            type: "string";
                            format: string;
                        };
                    };
                    additionalProperties: false;
                };
                see: {
                    version: {
                        major: number;
                        minor: number;
                        patch: number;
                    };
                    schema: {
                        type: "object";
                        title: string;
                        description: string;
                        properties: {
                            error: {
                                type: string[];
                                see: {
                                    version: {
                                        major: number;
                                        minor: number;
                                        patch: number;
                                    };
                                    schema: {
                                        type: "object";
                                        title: string;
                                        description: string;
                                        properties: {
                                            name: {
                                                type: string[];
                                                description: string;
                                            };
                                            message: {
                                                type: string[];
                                                description: string;
                                            };
                                            stack: {
                                                type: string[];
                                                description: string;
                                            };
                                            codeFrame: {
                                                type: string[];
                                                see: {
                                                    version: {
                                                        major: number;
                                                        minor: number;
                                                        patch: number;
                                                    };
                                                    schema: {
                                                        type: "object";
                                                        title: string;
                                                        description: string;
                                                        properties: {
                                                            line: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            column: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            originalFile: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            relativeFile: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            absoluteFile: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            frame: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                            language: {
                                                                type: string[];
                                                                description: string;
                                                            };
                                                        };
                                                        additionalProperties: true;
                                                    };
                                                    example: TestRunnerTestErrorExample100;
                                                };
                                                required: false;
                                                title: string;
                                                description: string;
                                                properties: {
                                                    line: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    column: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    originalFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    relativeFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    absoluteFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    frame: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    language: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                };
                                                additionalProperties: true;
                                            };
                                        };
                                        additionalProperties: true;
                                    };
                                    example: TestRunnerTestErrorExample100;
                                };
                                title: string;
                                description: string;
                                properties: {
                                    name: {
                                        type: string[];
                                        description: string;
                                    };
                                    message: {
                                        type: string[];
                                        description: string;
                                    };
                                    stack: {
                                        type: string[];
                                        description: string;
                                    };
                                    codeFrame: {
                                        type: string[];
                                        see: {
                                            version: {
                                                major: number;
                                                minor: number;
                                                patch: number;
                                            };
                                            schema: {
                                                type: "object";
                                                title: string;
                                                description: string;
                                                properties: {
                                                    line: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    column: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    originalFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    relativeFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    absoluteFile: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    frame: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                    language: {
                                                        type: string[];
                                                        description: string;
                                                    };
                                                };
                                                additionalProperties: true;
                                            };
                                            example: TestRunnerTestErrorExample100;
                                        };
                                        required: false;
                                        title: string;
                                        description: string;
                                        properties: {
                                            line: {
                                                type: string[];
                                                description: string;
                                            };
                                            column: {
                                                type: string[];
                                                description: string;
                                            };
                                            originalFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            relativeFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            absoluteFile: {
                                                type: string[];
                                                description: string;
                                            };
                                            frame: {
                                                type: string[];
                                                description: string;
                                            };
                                            language: {
                                                type: string[];
                                                description: string;
                                            };
                                        };
                                        additionalProperties: true;
                                    };
                                };
                                additionalProperties: true;
                            };
                            timings: {
                                type: string[];
                                description: string;
                                properties: {
                                    lifecycle: {
                                        type: "integer";
                                        minimum: number;
                                        description: string;
                                    };
                                    'before each': {
                                        type: "array";
                                        items: {
                                            type: "object";
                                        };
                                    };
                                };
                            };
                            failedFromHookId: {
                                type: string[];
                                format: string;
                            };
                            wallClockStartedAt: {
                                type: string[];
                                format: string;
                            };
                            wallClockDuration: {
                                type: string[];
                                minimum: number;
                            };
                            videoTimestamp: {
                                type: string[];
                            };
                            state: {
                                type: "string";
                                format: string;
                            };
                        };
                        additionalProperties: false;
                    };
                    example: TestRunnerTestAttemptExample100;
                };
            };
            testId: {
                type: "string";
                format: string;
                description: string;
            };
            title: {
                type: "array";
                items: {
                    type: "string";
                };
            };
            body: {
                type: string[];
                description: string;
            };
            state: {
                type: "string";
                format: string;
            };
        };
        required: true;
        additionalProperties: false;
    };
    example: TestRunnerTestExample200;
};
export declare const TestRunnerTest: import("@cypress/schema-tools").VersionedSchema;
export declare const TestRunnerTestAttempt: import("@cypress/schema-tools").VersionedSchema;
